function MeanBedrockError = BedrockTopoError(CLPath)
% Function extracts Bedrock topography error from the BedMachine V4 data set 
% along a centerline 
%
%
% arguments: (input)
% CLPath - Path to centerline data
%
%
% arguments: (output)
% MeanBedrockError - Average bedrock topography error

    ErrorData = 'Data/BedTopo/BedmachineV4_Error.tif';
    [Error,Rerror] = geotiffread(ErrorData);
    CL = shaperead(CLPath);
    
    lon0_err = Rerror.XWorldLimits(1);   % Top Left longitude coordinate from .vrt files
    lat0_err = Rerror.YWorldLimits(2); 
    dlon_err = Rerror.CellExtentInWorldX;
    dlat_err =  Rerror.CellExtentInWorldY;% stepping in lon/lat
    lon_err = lon0_err: dlon_err:Rerror.XWorldLimits(2);  % Create #vector of longitudes
    lat_err = lat0_err: -dlat_err:Rerror.YWorldLimits(1);
    
    LineCoordinates = [CL.X(1:end-1)' CL.Y(1:end-1)']; % Gets coordinates of the line

    
    BedrockError = improfile([min(lon_err) max(lon_err)],[min(lat_err) max(lat_err)],flipud(Error)...
        ,LineCoordinates(:,1),LineCoordinates(:,2)); % extracts the error along the line
    MeanBedrockError = mean(BedrockError);
end 




