function Results = CenterlineMethod(Termini,Centerline)
% Function calculates the Terminus position along the Centerline as well as
% the terminus position change between observations (Code adapted from
% MaQiT; Lea, J. M. (2018). The Google Earth Engine Digitisation Tool 
% (GEEDiT) and the Margin change Quantification Tool (MaQiT)–simple tools 
% for the rapid mapping and quantification of changing Earth surface margins. 
% Earth Surface Dynamics, 6(3), 551-561.)

% arguments(input):
% Termini       - Record of terminus positions
% Centerline    - Centerline along which terminus change is calculated
%
%arguments(output):
% Results.Date            - Date of terminus observations
% Results.RawDistance     -
% Results.Distance        - Terminus position change relative to most
%                           recent observation [m]
% Results.TerminusChange  - Terminus position change between individual
%                           observations [m]

for i=1:length(Termini)
    TerminiDate(i,1)= Termini{i}.Datenum;
end
CL_data = shaperead(Centerline);

for n=1:length(Termini)
    [term_intercept_dummyx,term_intercept_dummyy]=polyxpoly(CL_data.X,...
        CL_data.Y,Termini{n}.X,Termini{n}.Y);
    term_intercept_x(n,1:length(term_intercept_dummyx))=term_intercept_dummyx';
    term_intercept_y(n,1:length(term_intercept_dummyy))=term_intercept_dummyy';
end

term_intercept_x(term_intercept_x==0)=NaN;
term_intercept_y(term_intercept_y==0)=NaN;

a=0;

for n=1:length(Termini)
    for p=1:length(term_intercept_x(1,:))   %to take account where there are multiple intercepts
        distance_raw(n,p)=0;
        cutoff=0;
    for m=1:length(CL_data.X)-1
      if cutoff==0
          if ~isnan(term_intercept_x(n,p)) && term_intercept_x(n,p)~=0
            %compares if linear distance between centreline nodes or
            %between a node, and works way along centreline until intercept
            %is reached.
            dist_to_point=sqrt(((CL_data.X(1,m+1)-CL_data.X(1,m))^2)...
                +((CL_data.Y(1,m+1)-CL_data.Y(1,m))^2));
            dist_to_intercept=sqrt(((term_intercept_x(n,p)-CL_data.X(1,m))^2)...
                +((term_intercept_y(n,p)-CL_data.Y(1,m))^2));
            if dist_to_point<dist_to_intercept
                distance_raw(n,p)=distance_raw(n,p)+dist_to_point;
                centreline1{n,p}(m,1:2)=[CL_data.X(m),CL_data.Y(m)];
            elseif dist_to_point>dist_to_intercept || length(CL_data.X)==2
                centreline1{n,p}(m,1:2)=[term_intercept_x(n,p),term_intercept_y(n,p)];
                distance_raw(n,p)=distance_raw(n,p)+dist_to_intercept;
                cutoff=1;
            end
          else
             distance_raw(n,p)=NaN;
          end
      end
    end
    end
    
    %Get indicies of centreline lengths, taking shortest centreline
    %length where there are multiple intercepts.
    
    if distance_raw(n,1)>0  %leaves out termini where there is no intercept with centreline
        a=a+1;
        Results.Date(a,:)=TerminiDate(n,1:end);
        [Results.RawDistance(a,1),ind]=nanmin(distance_raw(n,:));

    end
end
    Results.Distance=Results.RawDistance-Results.RawDistance(end,1);
    Results.TerminusChange(1,1)=nan;
    for n=2:length(Results.Distance(:,1))
        %calculate terminus change
        Results.TerminusChange(n,1)=Results.Distance(n,1)-Results.Distance(n-1,1);
    end
end