function [UpperPoly,LowerPoly] = CreatePolygon(FW,FWl)
% Function creates polygons from fjord wall boundaries if boundary
% coordinates have been saved already. 
%
% arguments: (input)
% FW - Coordinates of upper fjord wall boundary
% FWl - Coordinates of lower fjord wall boundary
%
%
%
% arguments: (output)
% UpperPoly - Polygon based on FW
% LowerPoly - Polygon based on FWl


x1 = FW(1,1);
y1 = FW(1,2);
x2 = FW(end,1);
y2 = FW(end,2);

m = (y2-y1)/(x2-x1);
%%
if m>0
    if (FWl(end,1)==min(FWl(:,1)))==1 && (FWl(end,2)==min(FWl(:,2)))==1 || (FWl(1,1)==min(FWl(:,1)))==1 &&...
            (FWl(1,2)==min(FWl(:,2)))==1 
        xminLo = min(FWl(:,1));
        yminLo = min(FWl(:,2));
        xmaxLo = max(FWl(:,1));
        ymaxLo = max(FWl(:,2));
    elseif (FWl(1,1)==min(FWl(:,1)))==1 && sum((FWl(1,:)<FWl(end,:)))>1
        xminLo = min(FWl(:,1));
        yminLo = min(FWl(:,2));
        xmaxLo = max(FWl(:,1));
        ymaxLo = max(FWl(:,2));
    else
        xminLo = FWl(end,1);
        yminLo = FWl(end,2);
        xmaxLo = FWl(1,1);
        ymaxLo = FWl(1,2);
    end

    LoLine=[];
    if FWl(1,2)>FWl(end,2)
        LoLine(end+1,:) = [xmaxLo yminLo];
    else
        LoLine(1,:) = [xmaxLo yminLo];
    end


    LoLine= [LoLine;FWl];
    a=sum(LoLine(end,:)~=LoLine(1,:));
    b=sum(LoLine(end,:)==min(LoLine));
    if a>0 && b>=1
        LoLine(LoLine==LoLine(end,1))=xminLo;
        LoLine(LoLine==LoLine(end,2))=yminLo;
    elseif a==1 && b==0
%         LoLine(end,1)=xmaxLo;
%         LoLine(end,2)=yminLo;
        LoLine(1,1) = xminLo;
        LoLine(1,2) = yminLo;
    else
        LoLine(end,1)=xmaxLo;
        LoLine(end,2)=yminLo;
        LoLine(1,1) = xminLo;
        LoLine(1,2) = yminLo;
    end
    LowerPoly =polyshape(LoLine);
    
    % Upper boundary polygon
    xmaxUp = max(FW(:,1));
    xminUp = min(FW(:,1));
    ymaxUp = max(FW(:,2));
    yminUp = min(FW(:,2));

    UpLine=[];
    if FW(1,1)<0 ==1 
        UpLine(1,:) = [xminUp ymaxUp];
        UpLine= [UpLine;FW];
%         UpLine(end,:) = [xmaxUp ymaxUp];
        UpLine(end+1,:) = [xminUp ymaxUp];
    else
        UpLine=[];
        UpLine(1,:) = [xminUp ymaxUp];
        UpLine= [UpLine;FW];
        UpLine(end,:) = [xminUp ymaxUp];
    end
    UpperPoly =polyshape(UpLine);

else
    xminLo = min(FWl(:,1));
    yminLo = min(FWl(:,2));
    xmaxLo = max(FWl(:,1));
    
    LoLine=[];
    LoLine(1,:) = [xminLo yminLo];
    LoLine= [LoLine;FWl];
    
    if sum(LoLine(end,:)~=LoLine(1,:))>0 && sum(LoLine(end,:)==min(LoLine))==1
        LoLine(LoLine==LoLine(end,1))=xminLo;
        LoLine(LoLine==LoLine(end,2))=yminLo;
    else
        LoLine(end,1)=xmaxLo;
        LoLine(end,2)=yminLo;
    end
    LowerPoly =polyshape(LoLine);
    
    % Upper boundary polygon
    Connector = [FW(1,1) FW(1,2); FW(end,1) FW(end,2); FWl(1,1) FWl(1,2); FWl(end,1) FWl(end,2)];
    mid1=[(Connector(1,1)+Connector(2,1))/2, (Connector(1,2)+Connector(2,2))/2];
    mid2=[(Connector(3,1)+Connector(4,1))/2, (Connector(3,2)+Connector(4,2))/2];
    
    MidLine = [mid1;mid2];
    Direction = diff(MidLine);

    xmaxUp = max(FW(:,1));
    ymaxUp = max(FW(:,2));
    xminUp = min(FW(:,1));
    yminUp = min(FW(:,2));
    UpLine=[];    
    if m<-10
        UpLine=[];
        UpLine(1,:)= [xminUp, ymaxUp];
        UpLine = [FW;UpLine];
%         disp('Exception for high m')
    elseif FW(1,1)<0 ==1 && FW(1,2)<0==1 && (FW(1,2)>FW(end,2))==1 && (FW(1,2)>FWl(1,2))==1 && max(FW(:,2))==FW(1,2)...
            && max(FW(:,2))==FW(end,2)==1
        UpLine(1,:) = [xmaxUp,ymaxUp];
        UpLine= [FW;UpLine];
%         disp('Condition 1 Up, m neg')
    elseif FW(1,1)<0 ==1 && FW(1,2)<0==1 && (FW(1,2)<FW(end,2))==1 && Direction(:,2)>0==1
        UpLine(1,:) = [xminUp yminUp];
        UpLine= [UpLine;FW];
        if FW(end,1)==min(FW(:,1))
            UpLine(end,:) = [xminUp yminUp];
        else
            UpLine(end,:) = [xmaxUp, yminUp];
        end
%         disp('Condition 2 Up, m neg')
    elseif FW(1,2)~=max(FW(:,2))==1 && FW(end,2)~=max(FW(:,2))==1
        UpLine=[];
        UpLine(1,:) = [xminUp ymaxUp];
        UpLine= [UpLine;FW];
        UpLine(end,:) = [xmaxUp ymaxUp];
%         disp('Condition 2a Up, m neg')
  elseif FW(1,1)<0 ==1 && FW(1,2)<0==1 && (FW(1,2)<FW(end,2))==1 && Direction(:,2)<0
        UpLine(1,:) = [xmaxUp ymaxUp];
        UpLine= [UpLine;FW];


    elseif FW(1,1)<0 ==1 && FW(1,2)>0==1
        xmin = min(FW(:,1));
        UpLine(1,:) = [xminUp ymaxUp];
        UpLine= [UpLine;FW];
        UpLine(end,:) = [xmaxUp ymaxUp];
        UpLine(end+1,:) = [xminUp ymaxUp];

    elseif FW(1,1)<0 ==1 && FW(1,2)<0==1 && (FW(1,2)>FW(end,2))==0
        UpLine=[];
        UpLine(1,:) = [xminUp yminUp];
        UpLine= [UpLine;FW];

    else
        UpLine=[];
        UpLine(1,:) = [xmaxUp ymaxUp];
        UpLine= [UpLine;FW];
        UpLine(end,:) = [xmaxUp ymaxUp];
%         disp('Condition 5 Up, m neg')
    end
    UpperPoly =polyshape(UpLine);
end
end