function DE = DE_timeaveraging(Discharge,t)
% function to create average terminus position change from sparse
% and misaligned inputs

% INPUTS
% Discharge - Path to solid ice discharge
% t - intervals of time on which to output data
% i.e. data is averaged between t(i+1) and t(i)

% OUTPUTS - in structure s with fields:
% DE.tbounds - boundaries of time intervals on which output data defined
% DE.t - midpoint of time intervals on which output data defined
% DE.Derror - discharge during time intervals
% DE.Derror0 - discharge masking out interpolated values
%% interpolate terminus position change (TPC) to daily

    a = readtable(Discharge);
    a_unique = unique(a(:,2:4),'rows');
    tDE = datenum(table2array(a_unique(:,1)));
    DE0 = table2array(a_unique(:,3))/365.25;
    if all(isnan(DE0))==1
        DE=NaN;
    else
    
        DE_tdaily = [min(t):max(t)];
        DE_daily = interp1(tDE,DE0,DE_tdaily,'linear',NaN);
        
        % mean values over required intervals
        for i=1:length(t)-1
            inds = find(DE_tdaily>=t(i) & DE_tdaily<t(i+1));
            DE_new(i) = mean(DE_daily(inds));
        end
        %% create version of data with no interpolated values
        % mask TPC for values that are pure interpolation
        % for an interpolated value to be reliable need values either side
        inds = [];
        for i=2:length(t)-1
            if isempty(find(DE_tdaily>=t(i) & tDE<t(i+1)))
                 inds = [inds,i];
            end
        end
        % remove TPC values that are interpolated
        DE0 = DE_new; DE0(inds) = NaN;
        %% put into output structure
        DE.tbounds = t;
        DE.t = 0.5*(t(1:end-1)+t(2:end));
        DE.D_error = DE_new;
        DE.D_error0 = DE0;
    end
end