function BLN =LowerBoxBoundary(LandsatImage,R8,FW,FWl,Termini,GlacierName,OutFolder)
% Function sets lower boundary of box that is used to calculate the polygon
% area. The boundary should be set upstream of the most retreated terminus
% position and should cross both fjord walls. 

% arguments: (input)
% Landsat Image - Panchromatically sharpened Landsat image
% R8            - References matrix for Landsat image.
% FW            - Coordinates of upper fjord boundary
% FWl           - Coordinates of lower fjord boundary
% Termini       - All terminus positions
% GlacierName   - Name of the glacier
% OutFolder     - Path to folder where output is saved
%
%
% arguments: (output)
% BLN - X/Y coordinates of upstream boundary line

Red = LandsatImage(:,:,1);
Blue = LandsatImage(:,:,2);
Green = LandsatImage(:,:,3);
NormRed = (Red - min(Red(:)))/(max(Red(:)) - min(Red(:)));
NormBlue = (Blue - min(Blue(:)))/(max(Blue(:)) - min(Blue(:)));
NormGreen = (Green - min(Green(:)))/(max(Green(:)) - min(Green(:)));
NormRGB = double(cat(3,NormGreen,NormBlue,NormRed));
N=length(Termini);

f2=figure('units','normalized','outerposition',[0 0 1 1]);
mapshow(NormRGB,R8);
hold on
Col = parula(N);
for i=1:length(Termini)
    plot(Termini{i}.X,Termini{i}.Y,'Color',Col(i,:))
end
hold on
plot(FW(:,1),FW(:,2),'r','LineWidth',2);
hold on 
plot(FWl(:,1),FWl(:,2),'r','LineWidth',2);
waitfor(msgbox("Draw inland box boundary - MUST cross fjord walls"));
h = drawpolyline();
BoundaryLine = h.Position;


FjordUp(:,1) = FW(:,1);
FjordUp(:,2) = FW(:,2);
FjordLow(:,1) = FWl(:,1);
FjordLow(:,2) = FWl(:,2);

[BoundUp,BoundUp(:,2)] =polyxpoly(FjordUp(:,1),FjordUp(:,2),BoundaryLine(:,1),BoundaryLine(:,2));
[BoundLow,BoundLow(:,2)]=polyxpoly(FjordLow(:,1),FjordLow(:,2),BoundaryLine(:,1),BoundaryLine(:,2));


[~,Idx] = pdist2(FjordUp, BoundUp,'minkowski','Smallest',1);
[~,IdxL] = pdist2(FjordLow, BoundLow,'minkowski','Smallest',1);
BoundEndPoint = [FjordUp(Idx,1),FjordUp(Idx,2)];
BoundStartPoint = [FjordLow(IdxL,1),FjordLow(IdxL,2)];
BLN(1,:) = BoundEndPoint;
BLN(2,:) = BoundStartPoint;
BoundaryFolder=strcat(OutFolder,'/UpstreamBoundary/');
if ~exist(BoundaryFolder)
    mkdir(BoundaryFolder)
end

writematrix(BLN,strcat(BoundaryFolder,GlacierName,'.csv'))
close(f2)
end 