
% This script downloads its_live velocity mosaics. Just select your region 
% of interest and let it run. 
% Written by Chad Greene of NASA Jet Propulsion Laboratory, October 2020.
% Modified by Dominik Fahrner, University of Oregon, October 2022.

%% Set preferences: 
function VelocityFolder = VelocityDownload(varargin)
% answer= questdlg('Downloading velocity composite images (~16 GB) - This might take a while',...
%     'Velocity download',...
%     'Ok','Stop download','Stop download');
% switch answer
%     case 'Ok'

        if isempty(varargin)
            Defaults={2008,2018};
            OutFolder = 'Data/Velocity/NetCDF/';
        else
            Defaults={varargin{1},varargin{2}};
            OutFolder ='Data/Velocity/NetCDF/';
        end
        region = 'GRE';
        overwrite = false; % If true, this will download and overwrite files by the same name. If false, any existing files are not downloaded.
        
        yr = Defaults{2}:-1:Defaults{1}; % Download the overall mosaic first, then each year starting with most recent. 
        
        if ~exist(OutFolder)
            mkdir(OutFolder)
        end
        
        % Depending on the region and the speed of your internet connection, this might 
        % take a while. For example, each mosaic for the HMA region is a few hundred MB, 
        % so with my mediocre home internet connection it takes about 30 minutes to 
        % download all 30+ years of data. 
        
        % Loop through each year: 
        w = waitbar(0,'Downloading '); 
        for k = 1:length(yr)
              fn = [upper(region),'_G0240_',num2str(yr(k)),'.nc'];
              url = ['http://its-live-data.jpl.nasa.gov.s3.amazonaws.com/velocity_mosaic/landsat/v00.0/annual/',fn];
              waitbar((k-1)/length(yr),w,{['Downloading data from the ',num2str(yr(k)),' mosaic.'];'Going backward through time...'})
        %    end
           
           if exist(strcat(OutFolder,fn),'file')==2
              if ~overwrite
                 disp(['Skipping ',fn,' because it already exists.'])
                 continue % skips this mosaic if the user says don't overwrite existing files. 
              end
           end
           
           websave(strcat(OutFolder,fn),url);
        end
        
        waitbar(1,w,'Done') 
        pause(0.1) 
        close(w) 
        VelocityFolder=OutFolder; 

%     case 'Stop download'
%         uiwait(msgbox('Frontal Ablation can not be calculated without velocities - Calculation will stop!'))
%         VelocityFolder = [];
end
% end

