function [UpperFW,LowerFW,UpperPolygon,LowerPolygon]=drawFjordWalls(Landsat8image, ReferenceMatrix,Termini,GlacierName,outFolder,TerminusFlag)
% The function allows to manual delineation of upper and lower fjord walls 
% to create boundaries by using a panchromatically sharpened Landsat image.
% Then converts the delineated boundaries to polygons for further
% processing. 
% Also saves the coordinates of the resulting boundaries. 

% arguments: (input)
% Landsat8image     - Panchromatically sharpened NASA Landsat image of the AOI
% ReferenceMatrix   - Geographic matrix associated with the Landsat image
% GlacierName       - Name of the glacier
% Outfolder         - Path to folder where output is saved
%
%
%
% arguments: (output)
% UpperFW       - Coordinates of upper fjord wall boundaries
% Lower FW      - Coordinates of lower fjord wall boundaries
% UpperPolygon  - Polygon based on UpperFW
% LowerPolygon  - Polygon based on LowerFW

TP = shaperead(Termini);


Red = Landsat8image(:,:,1);
Blue = Landsat8image(:,:,2);
Green = Landsat8image(:,:,3);
NormRed = (Red - min(Red(:)))/(max(Red(:)) - min(Red(:)));
NormBlue = (Blue - min(Blue(:)))/(max(Blue(:)) - min(Blue(:)));
NormGreen = (Green - min(Green(:)))/(max(Green(:)) - min(Green(:)));
NormRGB =double(cat(3,NormRed,NormGreen,NormBlue));
%%
f1=figure('units','normalized','outerposition',[0 0 1 1]);
mapshow(NormRGB,ReferenceMatrix)
if TerminusFlag==1
hold on
    for i=1:length(TP)
        plot(TP(i).X,TP(i).Y);
        hold on
    end
end
waitfor(msgbox("Draw upper Fjordwall boundaries"));
DrawUpper =drawpolyline();
UpperFjordWall = DrawUpper.Position;
waitfor(msgbox("Draw lower Fjordwall boundaries"));
DrawLower = drawpolyline();
LowerFjordWall = DrawLower.Position;
close(f1)
%%
UfwX=[];
UfwY=[];
LfwX=[];
LfwY=[];

for i=1:length(UpperFjordWall(:,1))-1
    UfwX = [UfwX; linspace(UpperFjordWall(i,1),UpperFjordWall(i+1,1),100)'];
    UfwY = [UfwY; linspace(UpperFjordWall(i,2),UpperFjordWall(i+1,2),100)'];
end

for i=1:length(LowerFjordWall(:,1))-1
    LfwX = [LfwX; linspace(LowerFjordWall(i,1),LowerFjordWall(i+1,1),100)'];
    LfwY = [LfwY; linspace(LowerFjordWall(i,2),LowerFjordWall(i+1,2),100)'];
end

UpFW(:,1)=UfwX;
UpFW(:,2)=UfwY;
LoFW(:,1)=LfwX;
LoFW(:,2)=LfwY;

UpperFW = UpFW;
LowerFW = LoFW;

xmin = min(LowerFW(:,1));
ymin = min(LowerFW(:,2));

LoLine=[];
LoLine(1,:) = [xmin ymin];
LoLine= [LoLine;LowerFW];
LoLine(end,:) = [xmin ymin];
LowerPolygon =polyshape(LoLine);


% Upper boundary polygon
xmax = max(UpperFW(:,1));
ymax = max(UpperFW(:,2));

UpLine=[];
UpLine(1,:) = [xmax ymax];
UpLine= [UpLine;UpperFW];
UpLine(end,:) = [xmax ymax];
UpperPolygon =polyshape(UpLine);

BoundaryFolder=strcat(outFolder,'FjordBoundaries/');
if ~exist(BoundaryFolder, 'dir')
   mkdir(BoundaryFolder)
end


writematrix(UpperFW,strcat(BoundaryFolder,'UpperFW_',GlacierName,'.csv'))
writematrix(LowerFW,strcat(BoundaryFolder,'LowerFW_',GlacierName,'.csv'))
end

