
<p float="left">
  <img src="https://github.com/DominikFahrner/TG_FACT/blob/main/Logos/UOSignature-356.png" width="33%" />
  &nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;&nbsp; &nbsp; &nbsp; &nbsp;
  <img src="https://github.com/DominikFahrner/TG_FACT/blob/main/Logos/GRISO_Logo.png" width="33%" />
</p>


# Tidewater Glacier Frontal Ablation Calculation Tool (TG_FACT)
This processing chain and the associated dataset is described in Fahrner et al., 2023.   
When using this processing chain or dataset please cite:

*Fahrner, D., Slater, D. A., KC, A., Enderlin, E., Sutherland, D., Wagner, T., Nienow, P., de Jong,F., Nowicki, S.,
Slater, D., Wood, M., Kjeldsen, K.K., Cenedese, C. (2023): Frontal Ablation data for 49 tidewater glaciers.*


The processing chain will calculate monthly, three-monthly or annual frontal ablation for Greenlandic marine-temrinating glaciers based on the following input data:
1. TermPicks Terminus delineations (Goliber and Black, 2021).
2. Satellite image (for manual delineation of fjord walls).
3. Glacier velocity (code will automatically download ITS_LIVE velocities ~15 GB)
4. Two Digital Elevation Models (preferably ArcticDEM and AeroDEM; Porter et al., 2018, Korsgaard et al., 2016)
5. Surface change rate (Khan, 2017)
6. Bedrock Topography (BedMachine v4; Morlighem et al., 2017, 2021).
7. Solid Ice Discharge (Mankoff, 2019)

Example data (Boundaries, DEMs, Terminus Positions, Discharge) is provided for Helheim Glacier, SW Greenland. 

## Processing Steps
1. Terminus traces are clipped or extrapolated to fjord wall boundaries
2. Polygon for each terminus trace is created (with consistent arbirtray boundary upstream of the termius)
3. Volume is derived using surface change rate (where available) and mean surface change between ArcticDEM and AeroDEM (Figure 1)

<p float="center">
  <img src="https://github.com/DominikFahrner/TG_FACT/blob/main/Images/SurfaceChangeFlowChart.jpg" width="50%" />
</p>
<p>
    <em>Figure 1: Flow chart showing the calculation of ice thickness</em>
</p>

4. Mass is then calculated using assuming constant ice density (0.917 g/cm<sup>3</sup>)
5. The mass is interpolated to the first of each month and mass change is calculated (and averaged depending on user input)
6. The code further calculates the maximum uncertainty for each glacier

<p float="center">
  <img src="https://github.com/DominikFahrner/TG_FACT/blob/main/Images/Helheim_Gletsjer.jpg" width="50%" />
</p>
<p>
    <em>Figure 2: Example of code output for Helheim Glacier, SW Greenland</em>
</p>




## Example
The following example data for Helheim Glacier, SW Greenland is provided in the "Data" and "Results" folder:
- Terminus positions from TermPicks (Goliber and Black, 2021)
- Centerlines
- Glacier Centerlines (for extraction of bedrock topography)
- Ice discharge estimates with associated error (Mankoff, 2019)
- Surface elevation change rate (Khan, 2017)
- Upper, lower and upstream fjord boundaries (for reproducability)

Due to the file size limit of GitHub, the following data needs to be downloaded:
- ArcticDEM and AeroDEM: https://drive.google.com/drive/folders/1JkFXtCClkIaiMEPWLIARAUjiUQov_coj?usp=share_link
- Processed bedrock topography (Bedmachine v4 topography and associated error as .Tif file):
  https://drive.google.com/drive/folders/1Fj1n5B-GRqgOqNIkloeFo5PtmYCtyX9U?usp=share_link 
Note: The data has to be saved in the "Data" folder!

To run the processing chain, run the TG_Fact_Runfile.m


## References
Goliber, S. and Black, T., (2021) TermPicks: A century of Greenland glacier terminus data for use inmachine learning applications. [online] Available at: https://zenodo.org/record/5117931 [Accessed 27 May 2022].

Khan, S.A., (2017) Greenland Ice Sheet Surface Elevation Change. Available at: http://promice.org/PromiceDataPortal/api/download/90fb4cbf-e88e-4e26-af95-a47d19a9cf10.

Korsgaard, N.J., Nuth, C., Khan, S.A., Kjeldsen, K.K., Bjørk, A.A., Schomacker, A. and Kjær, K.H., (2016) Digital elevation model and orthophotographs of Greenland based on aerial photographs from 1978–1987. Scientific Data, [online] 31, p.160032. Available at: https://doi.org/10.1038/sdata.2016.32.

Mankoff, K.D., (2019) Ice dicharge for the Greenland ice sheet. Available at: https://doi.org/10.22008/PROMICE/DATA/ICE_DISCHARGE.

Morlighem, M., Williams, C., Rignot, E., An, L., Arndt, J.E., Bamber, J., Catania, G., Chauché, N., Dowdeswell, J.A., Dorschel, B., Fenty, I., Hogan, K., Howat, I., Hubbard, A., Jakobsson, M., Jordan, T.M., Kjeldsen, K.K., Millan, R., Mayer, L., Mouginot, J., Noël, B., O’Cofaigh, C., Palmer, S.J., Rysgaard, S., Seroussi, H., Siegert, M.J., Slabon, P., Straneo, F., Broeke, M.R. van den, Weinrebe, W., Wood, M. and Zinglersen, K., (2021) IceBridge BedMachine Greenland, Version 4.

Morlighem, M., Williams, C.N., Rignot, E., An, L., Arndt, J.E., Bamber, J.L., Catania, G., Chauché, N., Dowdeswell, J.A., Dorschel, B. and others, (2017) BedMachine v3: Complete bed topography and ocean bathymetry mapping of Greenland from multibeam echo sounding combined with mass conservation. Geophysical research letters, 4421.

Porter, C., Morin, P., Howat, I., Noh, M.-J., Bates, B., Peterman, K., Keesey, S., Schlenk, M., Gardiner, J., Tomko, K., Willis, M., Kelleher, C., Cloutier, M., Husby, E., Foga, S., Nakamura, H., Platson, M., Wethington Jr., M., Williamson, C., Bauer, G., Enos, J., Arnold, G., Kramer, W., Becker, P., Doshi, A., D’Souza, C., Cummens, P., Laurier, F. and Bojesen, M.A.-N.S.F.A.-N.S.F., (2018) ArcticDEM. V1 ed. Available at: https://doi.org/10.7910/DVN/OHHUKH.
